#[repr(C)]pub struct TfLiteExternalContext {
pub type_: TfLiteExternalContextType,
pub Refresh: Option<unsafe extern "C" fn(context: *mut TfLiteContext) -> TfLiteStatus>,
}Expand description
An external context is a collection of information unrelated to the TF Lite framework, but useful to a subset of the ops. TF Lite knows very little about the actual contexts, but it keeps a list of them, and is able to refresh them if configurations like the number of recommended threads change.
Fields
type_: TfLiteExternalContextTypeRefresh: Option<unsafe extern "C" fn(context: *mut TfLiteContext) -> TfLiteStatus>Trait Implementations
Sourceimpl Clone for TfLiteExternalContext
impl Clone for TfLiteExternalContext
Sourcefn clone(&self) -> TfLiteExternalContext
fn clone(&self) -> TfLiteExternalContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TfLiteExternalContext
impl Debug for TfLiteExternalContext
impl Copy for TfLiteExternalContext