TfLiteNode

Struct TfLiteNode 

#[repr(C)]
pub struct TfLiteNode { pub inputs: *mut TfLiteIntArray, pub outputs: *mut TfLiteIntArray, pub intermediates: *mut TfLiteIntArray, pub temporaries: *mut TfLiteIntArray, pub user_data: *mut c_void, pub builtin_data: *mut c_void, pub custom_initial_data: *const c_void, pub custom_initial_data_size: c_int, pub delegate: *mut TfLiteDelegate, pub might_have_side_effect: bool, }
A structure representing an instance of a node. This structure only exhibits the inputs, outputs, user defined data and some node properties (like statefulness), not other features like the type.

Fields

inputs: *mut TfLiteIntArray

Inputs to this node expressed as indices into the simulator’s tensors.

outputs: *mut TfLiteIntArray

Outputs to this node expressed as indices into the simulator’s tensors.

intermediates: *mut TfLiteIntArray

intermediate tensors to this node expressed as indices into the simulator’s tensors.

temporaries: *mut TfLiteIntArray

Temporary tensors uses during the computations. This usually contains no tensors, but ops are allowed to change that if they need scratch space of any sort.

user_data: *mut c_void

Opaque data provided by the node implementer through Registration.init.

builtin_data: *mut c_void

Opaque data provided to the node if the node is a builtin. This is usually a structure defined in builtin_op_data.h

custom_initial_data: *const c_void

Custom initial data. This is the opaque data provided in the flatbuffer.

WARNING: This is an experimental interface that is subject to change.

custom_initial_data_size: c_intdelegate: *mut TfLiteDelegate

The pointer to the delegate. This is non-null only when the node is created by calling interpreter.ModifyGraphWithDelegate.

WARNING: This is an experimental interface that is subject to change.

might_have_side_effect: bool

Whether this op might have side effect (e.g. stateful op).