TfLiteQuantization

Struct TfLiteQuantization 

#[repr(C)]
pub struct TfLiteQuantization { pub type_: TfLiteQuantizationType, pub params: *mut c_void, }
Structure specifying the quantization used by the tensor, if-any.

Fields

type_: TfLiteQuantizationType

The type of quantization held by params.

params: *mut c_void

Holds an optional reference to a quantization param structure. The actual type depends on the value of the type field (see the comment there for the values and corresponding types).