TfLiteTensor

Struct TfLiteTensor 

#[repr(C)]
pub struct TfLiteTensor {
Show 15 fields pub type_: TfLiteType, pub data: TfLitePtrUnion, pub dims: *mut TfLiteIntArray, pub params: TfLiteQuantizationParams, pub allocation_type: TfLiteAllocationType, pub bytes: usize, pub allocation: *const c_void, pub name: *const c_char, pub delegate: *mut TfLiteDelegate, pub buffer_handle: TfLiteBufferHandle, pub data_is_stale: bool, pub is_variable: bool, pub quantization: TfLiteQuantization, pub sparsity: *mut TfLiteSparsity, pub dims_signature: *const TfLiteIntArray,
}

Fields

type_: TfLiteType

The data type specification for data stored in data. This affects what member of data union should be used.

data: TfLitePtrUnion

A union of data pointers. The appropriate type should be used for a typed tensor based on type.

dims: *mut TfLiteIntArray

A pointer to a structure representing the dimensionality interpretation that the buffer should have. NOTE: the product of elements of dims and the element datatype size should be equal to bytes below.

params: TfLiteQuantizationParams

Quantization information.

allocation_type: TfLiteAllocationType

How memory is mapped kTfLiteMmapRo: Memory mapped read only. i.e. weights kTfLiteArenaRw: Arena allocated read write memory (i.e. temporaries, outputs).

bytes: usize

The number of bytes required to store the data of this Tensor. I.e. (bytes of each element) * dims[0] * … * dims[n-1]. For example, if type is kTfLiteFloat32 and dims = {3, 2} then bytes = sizeof(float) * 3 * 2 = 4 * 3 * 2 = 24.

allocation: *const c_void

An opaque pointer to a tflite::MMapAllocation

name: *const c_char

Null-terminated name of this tensor.

delegate: *mut TfLiteDelegate

The delegate which knows how to handle buffer_handle.

WARNING: This is an experimental interface that is subject to change.

buffer_handle: TfLiteBufferHandle

An integer buffer handle that can be handled by delegate. The value is valid only when delegate is not null.

WARNING: This is an experimental interface that is subject to change.

data_is_stale: bool

If the delegate uses its own buffer (e.g. GPU memory), the delegate is responsible to set data_is_stale to true. delegate->CopyFromBufferHandle can be called to copy the data from delegate buffer.

WARNING: This is an experimental interface that is subject to change.

is_variable: bool

True if the tensor is a variable.

quantization: TfLiteQuantization

Quantization information. Replaces params field above.

sparsity: *mut TfLiteSparsity

Parameters used to encode a sparse tensor. This is optional. The field is NULL if a tensor is dense.

WARNING: This is an experimental interface that is subject to change.

dims_signature: *const TfLiteIntArray

Optional. Encodes shapes with unknown dimensions with -1. This field is only populated when unknown dimensions exist in a read-write tensor (i.e. an input or output tensor). (e.g. dims contains [1, 1, 1, 3] and dims_signature contains [1, -1, -1, 3]). If no unknown dimensions exist then dims_signature is either null, or set to an empty array. Note that this field only exists when TF_LITE_STATIC_MEMORY is not defined.