TfLiteAllocationStrategy

Type Alias TfLiteAllocationStrategy 

pub type TfLiteAllocationStrategy = c_uint;
Memory allocation strategies.

TfLiteAllocationType values have been overloaded to mean more than their original intent. This enum should only be used to document the allocation strategy used by a tensor for it data.