pub type TfLiteExternalContextType = c_uint;Expand description
The list of external context types known to TF Lite. This list exists solely to avoid conflicts and to ensure ops can share the external contexts they need. Access to the external contexts is controlled by one of the corresponding support files.