#[repr(C)]pub struct TfLiteEvalTensor {
pub data: TfLitePtrUnion,
pub dims: *mut TfLiteIntArray,
pub type_: TfLiteType,
}Expand description
Light-weight tensor struct for TF Micro runtime. Provides the minimal amount of information required for a kernel to run during TfLiteRegistration::Eval.
Fields
data: TfLitePtrUnionA union of data pointers. The appropriate type should be used for a typed
tensor based on type.
dims: *mut TfLiteIntArrayA pointer to a structure representing the dimensionality interpretation that the buffer should have.
type_: TfLiteTypeThe data type specification for data stored in data. This affects
what member of data union should be used.